<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Et problem oppsto med å (de)aktivere adresseboken.",
"id is not set." => "id er ikke satt.",
"Cannot update addressbook with an empty name." => "Kan ikke oppdatere adressebøker uten navn.",
"No ID provided" => "Ingen ID angitt",
"Error setting checksum." => "Feil under skriving av sjekksum",
"No categories selected for deletion." => "Ingen kategorier valgt for sletting.",
"No address books found." => "Ingen adressebok funnet.",
"No contacts found." => "Ingen kontakter funnet.",
"element name is not set." => "navn på elementet er ikke satt.",
"checksum is not set." => "sjekksumm er ikke satt.",
"Information about vCard is incorrect. Please reload the page." => "Informasjonen om vCard-filen er ikke riktig. Last inn siden på nytt.",
"Something went FUBAR. " => "Noe gikk fryktelig galt.",
"No contact ID was submitted." => "Ingen kontakt ID ble gitt",
"Error reading contact photo." => "Klarte ikke å lese kontaktbilde.",
"Error saving temporary file." => "Klarte ikke å lagre midlertidig fil.",
"The loading photo is not valid." => "Bildet som lastes inn er ikke gyldig.",
"Contact ID is missing." => "Kontakt-ID mangler.",
"No photo path was submitted." => "Ingen filsti ble lagt inn.",
"File doesn't exist:" => "Filen eksisterer ikke:",
"Error loading image." => "Klarte ikke å laste bilde.",
"Error getting contact object." => "Feil ved henting av kontakt objektet.",
"Error getting PHOTO property." => "Feil ved henting av foto verdi.",
"Error saving contact." => "Klarte ikke å lagre kontakt.",
"Error resizing image" => "Klarte ikke å endre størrelse på bildet",
"Error cropping image" => "Klarte ikke å beskjære bildet",
"Error creating temporary image" => "Klarte ikke å lage et midlertidig bilde",
"Error finding image: " => "Kunne ikke finne bilde:",
"Error uploading contacts to storage." => "Klarte ikke å laste opp kontakter til lagringsplassen",
"There is no error, the file uploaded with success" => "Pust ut, ingen feil. Filen ble lastet opp problemfritt",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Filen du prøvde å laste opp var større enn grensen upload_max_filesize i php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Filen du prøvde å laste opp var større enn grensen satt i MAX_FILE_SIZE i HTML-skjemaet.",
"The uploaded file was only partially uploaded" => "Filen du prøvde å laste opp ble kun delvis lastet opp",
"No file was uploaded" => "Ingen filer ble lastet opp",
"Missing a temporary folder" => "Mangler midlertidig mappe",
"Couldn't save temporary image: " => "Kunne ikke lagre midlertidig bilde:",
"Couldn't load temporary image: " => "Kunne ikke laste midlertidig bilde:",
"No file was uploaded. Unknown error" => "Ingen filer ble lastet opp. Ukjent feil.",
"Contacts" => "Kontakter",
"Select photo" => "Velg bilde",
"Error" => "Feil",
"Importing..." => "Importerer...",
"Unable to upload your file as it is a directory or has 0 bytes" => "Kan ikke laste opp filen din siden det er en mappe eller den har 0 bytes",
"Upload Error" => "Opplasting feilet",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Filen du prøver å laste opp er for stor.",
"Upload too large" => "Filen er for stor",
"Pending" => "Ventende",
"No files selected for upload." => "Ingen filer valgt for opplasting.",
"Favorites" => "Favoritter",
"Result: " => "Resultat:",
" imported, " => "importert,",
" failed." => "feilet.",
"Download" => "Hent ned",
"Edit" => "Rediger",
"Delete" => "Slett",
"Cancel" => "Avbryt",
"More..." => "Mer...",
"Less..." => "Mindre...",
"You do not have the permissions to delete this addressbook." => "Du har ikke tilgang til å slette denne adresseboken",
"There was an error deleting this addressbook." => "Det oppstod en feil under sletting av denne adresseboken",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Arbeid",
"Home" => "Hjem",
"Other" => "Annet",
"Mobile" => "Mobil",
"Text" => "Tekst",
"Voice" => "Svarer",
"Message" => "Melding",
"Fax" => "Faks",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internett",
"{name}'s Birthday" => "{name}s bursdag",
"Contact" => "Kontakt",
"Could not find the vCard with ID." => "Kunne ikke finne vCard med denne IDen",
"You do not have the permissions to edit this contact." => "Du har ikke tilgang til å endre denne kontakten.",
"Could not find the vCard with ID: " => "Kunne ikke finne vCard med denne IDen:",
"You do not have the permissions to delete this contact." => "Du har ikke tilgang til å slette denne kontakten.",
"There was an error deleting this contact." => "Det oppstod en feil ved sletting av denne kontakten",
"New Group" => "Ny gruppe",
"Settings" => "Innstillinger",
"Import" => "Importer",
"Select files" => "Velg filer",
"OK" => "OK",
"New Contact" => "Ny kontakt",
"Groups" => "Grupper",
"Delete Contact" => "Slett kontakt",
"Close" => "Lukk",
"Keyboard shortcuts" => "Tastatur snarveier",
"Navigation" => "Navigasjon",
"Next contact in list" => "Neste kontakt i listen",
"Previous contact in list" => "Forrige kontakt i listen",
"Expand/collapse current addressbook" => "Vis/skjul adresseboken",
"Add new contact" => "Legg til ny kontakt",
"Add new addressbook" => "Legg til ny adressebok",
"Delete current contact" => "Slett kontakten",
"Add contact" => "Ny kontakt",
"Delete current photo" => "Fjern nåværende bilde",
"Edit current photo" => "Rediger nåværende bilde",
"Upload new photo" => "Last opp nytt bilde",
"Select photo from ownCloud" => "Velg bilde fra ownCloud",
"First name" => "Fornavn",
"Additional names" => "Ev. mellomnavn",
"Last name" => "Etternavn",
"Nickname" => "Kallenavn",
"Enter nickname" => "Skriv inn kallenavn",
"Title" => "Tittel",
"Organization" => "Organisasjon",
"Birthday" => "Bursdag",
"Add" => "Legg til",
"Phone" => "Telefon",
"Email" => "E-post",
"Address" => "Adresse",
"Note" => "Notat",
"Web site" => "Hjemmeside",
"Delete contact" => "Slett kontakt",
"Preferred" => "Foretrukket",
"Please specify a valid email address." => "Vennligst angi en gyldig e-postadresse.",
"Mail to address" => "Send e-post til adresse",
"Delete email address" => "Fjern e-postadresse",
"Enter phone number" => "Skriv inn telefonnummer",
"Delete phone number" => "Fjern telefonnummer",
"View on map" => "Se på kart",
"City" => "By",
"Country" => "Land",
"Share" => "Del",
"Export" => "Eksporter",
"The temporary image has been removed from cache." => "Det midlertidige bildet er fjernet fra cache.",
"CardDAV syncing addresses" => "Synkroniseringsadresse for CardDAV",
"more info" => "mer info",
"Primary address (Kontact et al)" => "Primær adresse (kontakt osv)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adressebøker",
"New Address Book" => "Ny adressebok",
"Name" => "Navn",
"Description" => "Beskrivelse",
"Save" => "Lagre"
);
